from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.models_list_versions_json_body import ModelsListVersionsJsonBody
from ...models.models_list_versions_response_200_item import \
    ModelsListVersionsResponse200Item
from ...models.models_list_versions_response_400 import \
    ModelsListVersionsResponse400
from ...models.models_list_versions_response_401 import \
    ModelsListVersionsResponse401
from ...models.models_list_versions_response_500 import \
    ModelsListVersionsResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ModelsListVersionsJsonBody,

) -> Dict[str, Any]:
    url = "{}/v1/api/models/list_versions".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    if response.status_code == 500:
        response_500 = ModelsListVersionsResponse500.from_dict(response.json())



        return response_500
    if response.status_code == 400:
        response_400 = ModelsListVersionsResponse400.from_dict(response.json())



        return response_400
    if response.status_code == 401:
        response_401 = ModelsListVersionsResponse401.from_dict(response.json())



        return response_401
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in (_response_200):
            response_200_item = ModelsListVersionsResponse200Item.from_dict(response_200_item_data)



            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ModelsListVersionsJsonBody,

) -> Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    """Retrieve versions of a model

     Returns all versions for a given model.

    Args:
        json_body (ModelsListVersionsJsonBody):  Request for getting model versions

    Returns:
        Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)

def sync(
    *,
    client: Client,
    json_body: ModelsListVersionsJsonBody,

) -> Optional[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    """Retrieve versions of a model

     Returns all versions for a given model.

    Args:
        json_body (ModelsListVersionsJsonBody):  Request for getting model versions

    Returns:
        Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]
    """


    return sync_detailed(
        client=client,
json_body=json_body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    json_body: ModelsListVersionsJsonBody,

) -> Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    """Retrieve versions of a model

     Returns all versions for a given model.

    Args:
        json_body (ModelsListVersionsJsonBody):  Request for getting model versions

    Returns:
        Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)

async def asyncio(
    *,
    client: Client,
    json_body: ModelsListVersionsJsonBody,

) -> Optional[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]:
    """Retrieve versions of a model

     Returns all versions for a given model.

    Args:
        json_body (ModelsListVersionsJsonBody):  Request for getting model versions

    Returns:
        Response[Union[List[ModelsListVersionsResponse200Item], ModelsListVersionsResponse400, ModelsListVersionsResponse401, ModelsListVersionsResponse500]]
    """


    return (await asyncio_detailed(
        client=client,
json_body=json_body,

    )).parsed

